#!/bin/sh
#
# patching driverupdate
# Uwe Gansert <uwe.gansert@suse.de>
#
# Version 0.6
#

DECODED="/tmp/ay_update.tgz"
TMP_MOUNT="/tmp/ay_update_tmp_mount"
VERBOSE=1
BACKUP=`date +"%m_%d_%H_%m_%S"`
BACKUP="linux_$BACKUP"
MD5=""
DU_MUST_EXIST=1
DO_IMAGE=1

error()
{
    echo "ERROR!"
    echo -e "  $1"
    exit -1
}

logging()
{
    if [ "$VERBOSE" == "1" ]; then
        echo -e "  $1"
    fi
}

if [ "$DO_IMAGE" == "1" ]; then
    MKFS=`which mkfs.cramfs 2>/dev/null`;
    if [ -z "$MKFS" ]; then
        error "mkfs.cramfs needed but can't be found"
    fi;
fi;

if [ ! -d "./linux" ]; then
    logging "no extracted driverupdate found. Looking for image"
    if [ -s driverupdate ]; then
        logging "driverupdate image found"
        RSYNC=`which rsync`
        logging "rsync found: $RSYNC"
        if [ -z "$RSYNC" ]; then
            error "rsync is needed but can't be found"
        fi
        mkdir -p "$TMP_MOUNT" || error "  mkdir "$TMP_MOUNT" failed"
        logging "mounting driverupdate to $TMP_MOUNT"
        mount -oloop driverupdate "$TMP_MOUNT" || error "  mount -oloop driverupdate "$TMP_MOUNT" failed"
        logging "copy driverupdate content"
        $RSYNC -a "${TMP_MOUNT}/linux" . || error "  rsync -a \"${TMP_MOUNT}/linux\" . failed"
        umount "$TMP_MOUNT"
        rmdir "$TMP_MOUNT"
    else
        if [ $DU_MUST_EXIST == "1" ]; then
            error "driverupdate not found. Wrong directory?"
        fi;
        logging "no driverupdate image found. A new driverupdate will be created."
    fi
else
    logging "already extracted driverupdate found."
    logging "doing backup to $BACKUP"
    cp -a linux $BACKUP
fi

logging "decode patch to $DECODED"
#$OPENSSL base64 -d -out "$DECODED" <<EOT
perl -MMIME::Base64 -e "print decode_base64('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');" > $DECODED
#EOT

if [ ! -s "$DECODED" ]; then
    error "decoding update tar failed"
fi

if [ ! -z "$MD5" ]; then
    if [ `md5sum $DECODED` != "$MD5" ]; then
        error "MD5SUM of $DECODED is wrong"
    fi
fi;

tar xfz "$DECODED" || error "unpacking update tar failed"
rm -f "$DECODED"

logging "patching driverupdate was a success"

if [ "$DO_IMAGE" == "1" ]; then
        logging "creating image"
        mkdir ay_tmp
        mv linux ay_tmp
        rm -f driverupdate
        $MKFS ay_tmp driverupdate
        rm -rf ay_tmp
fi;

exit 0
